package com.caimei.wxController;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.WxClubListVo;
import com.caimei.model.vo.WxProductListVo;
import com.caimei.service.AuthClubService;
import com.caimei.service.AuthProductService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author Aslee
 */
@Api(tags = "微信品牌认证API")
@Slf4j
@RestController
@RequiredArgsConstructor
@RequestMapping("/wx/auth")
public class WxAuthApi {
    private final AuthClubService authClubService;

    private final AuthProductService authProductService;

    @ApiOperation("已认证机构列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "appId", required = true, value = "供应商公众号appId"),
            @ApiImplicitParam(name = "clubName", required = false, value = "机构名称"),
            @ApiImplicitParam(name = "pageNum", required = false, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = false, value = "一页多少条")
    })
    @GetMapping("/club/list")
    public ResponseJson<PageInfo<WxClubListVo>> getWxClubList(String appId, String clubName,
                                                              @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                              @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        return authClubService.getWxClubList(appId, clubName, pageNum, pageSize);
    }


    @ApiOperation("已认证商品列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "authId", required = true, value = "认证机构id"),
            @ApiImplicitParam(name = "productName", required = false, value = "商品名称"),
            @ApiImplicitParam(name = "pageNum", required = false, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = false, value = "一页多少条")
    })
    @GetMapping("/product/list")
    public ResponseJson<PageInfo<WxProductListVo>> getWxProductList(Integer authId, String productName,
                                                                    @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                                    @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        return authProductService.getWxProductList(authId, productName, pageNum, pageSize);
    }
}
